@@ -7,7 +7,7 @@ BEGIN {
 }
 
 {
-  $Set::Associate::Utils::VERSION = '0.002000';
+  $Set::Associate::Utils::VERSION = '0.003000';
 }
 
 
@@ -15,16 +15,16 @@ BEGIN {
 
   use strict;
 
-  sub _croak {
-    require Carp;
-    goto \&Carp::croak;
-  }
-
   sub _carp {
     require Carp;
     goto \&Carp::carp;
   }
 
+  sub _blessed {
+    require Scalar::Util;
+    goto \&Scalar::Util::blessed;
+  }
+
   sub _warn_nonmethod {
     if ( defined $_[0] and not ref $_[0] ) {
       return if $_[0]->isa( $_[1] );
@@ -36,38 +36,6 @@ BEGIN {
     return 1;
   }
 
-  sub _blessed {
-    require Scalar::Util;
-    goto \&Scalar::Util::blessed;
-  }
-
-  sub _tc_coderef {
-    return if defined $_[0] and ref $_[0] eq 'CODE';
-    _croak('Should be CodeRef');
-  }
-
-  sub _tc_str {
-    return if defined $_[0] and not ref $_[0];
-    _croak('should be Str');
-  }
-
-  sub _tc_arrayref {
-    return if ref $_[0] and ref $_[0] eq 'ARRAY';
-    _croak('should be ArrayRef');
-  }
-
-  sub _tc_hashref {
-    return if ref $_[0] and ref $_[0] eq 'HASH';
-    _croak('Should be HashRef');
-  }
-
-  sub _tc_bless {
-    my ($class) = @_;
-    return sub {
-      return if _blessed( $_[0] ) and $_[0]->isa($class);
-      _croak( 'Should be a ' . $class );
-    };
-  }
 };
 
 1;
@@ -84,7 +52,7 @@ Set::Associate::Utils - Shared Guts between Set::Associate modules
 
 =head1 VERSION
 
-version 0.002000
+version 0.003000
 
 =head1 AUTHOR
 
